pub struct Inputs {
pub one: DigitalInput,
pub two: DigitalInput,
pub three: DigitalInput,
}Expand description
Container for digital input controls on the Automation HAT.
Provides access to the three digital inputs available on all HAT variants.
Fields
one: DigitalInputDigital Input 1
two: DigitalInputDigital Input 2
three: DigitalInputDigital Input 3
Implementations
Sourceimpl Inputs
impl Inputs
Sourcepub fn new(one: DigitalInput, two: DigitalInput, three: DigitalInput) -> Self
pub fn new(one: DigitalInput, two: DigitalInput, three: DigitalInput) -> Self
Creates a new Inputs container with the specified digital input instances.
Arguments
one- Digital Input 1 instancetwo- Digital Input 2 instancethree- Digital Input 3 instance