pub struct Outputs {
pub one: DigitalOutput,
pub two: DigitalOutput,
pub three: DigitalOutput,
}Expand description
Container for digital output controls on the Automation HAT.
Provides access to the three digital outputs available on all HAT variants.
Fields
one: DigitalOutputDigital Output 1
two: DigitalOutputDigital Output 2
three: DigitalOutputDigital Output 3
Implementations
Sourceimpl Outputs
impl Outputs
Sourcepub fn new(one: DigitalOutput, two: DigitalOutput, three: DigitalOutput) -> Self
pub fn new(one: DigitalOutput, two: DigitalOutput, three: DigitalOutput) -> Self
Creates a new Outputs container with the specified digital output instances.
Arguments
one- Digital Output 1 instancetwo- Digital Output 2 instancethree- Digital Output 3 instance